==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/securityandcompliance/kotlin/outputs/ServiceCorsConfigurationInfoResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityandcompliance.kotlin.outputs

import kotlin.Boolean
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * The settings for the CORS configuration of the service instance.
 * @property allowCredentials If credentials are allowed via CORS.
 * @property headers The headers to be allowed via CORS.
 * @property maxAge The max age to be allowed via CORS.
 * @property methods The methods to be allowed via CORS.
 * @property origins The origins to be allowed via CORS.
 */
public data class ServiceCorsConfigurationInfoResponse(
    public val allowCredentials: Boolean? = null,
    public val headers: List<String>? = null,
    public val maxAge: Double? = null,
    public val methods: List<String>? = null,
    public val origins: List<String>? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.securityandcompliance.outputs.ServiceCorsConfigurationInfoResponse):
            ServiceCorsConfigurationInfoResponse = ServiceCorsConfigurationInfoResponse(
            allowCredentials = javaType.allowCredentials().map({ args0 -> args0 }).orElse(null),
            headers = javaType.headers().map({ args0 -> args0 }),
            maxAge = javaType.maxAge().map({ args0 -> args0 }).orElse(null),
            methods = javaType.methods().map({ args0 -> args0 }),
            origins = javaType.origins().map({ args0 -> args0 }),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/securityandcompliance/kotlin/outputs/ServiceCorsConfigurationInfoResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityandcompliance.kotlin.outputs

import kotlin.Boolean
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * The settings for the CORS configuration of the service instance.
 * @property allowCredentials If credentials are allowed via CORS.
 * @property headers The headers to be allowed via CORS.
 * @property maxAge The max age to be allowed via CORS.
 * @property methods The methods to be allowed via CORS.
 * @property origins The origins to be allowed via CORS.
 */
public data class ServiceCorsConfigurationInfoResponse(
    public val allowCredentials: Boolean? = null,
    public val headers: List<String>? = null,
    public val maxAge: Double? = null,
    public val methods: List<String>? = null,
    public val origins: List<String>? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.securityandcompliance.outputs.ServiceCorsConfigurationInfoResponse): ServiceCorsConfigurationInfoResponse = ServiceCorsConfigurationInfoResponse(
            allowCredentials = javaType.allowCredentials().map({ args0 -> args0 }).orElse(null),
            headers = javaType.headers().map({ args0 -> args0 }),
            maxAge = javaType.maxAge().map({ args0 -> args0 }).orElse(null),
            methods = javaType.methods().map({ args0 -> args0 }),
            origins = javaType.origins().map({ args0 -> args0 }),
        )
    }
}
